import * as React from 'react';
import { Table, Button, Header, Container, Menu, Icon } from 'semantic-ui-react';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import Probe from '@overflow/probe/api/model/Probe';
import History from '@overflow/history/api/model/History';

export interface StateProps {
  probeId: string;
  histories: History[];
}

export interface DispatchProps {
  onReadAllByProbe?(probe: Probe): void;
}

export type Props = StateProps & DispatchProps;

export interface State {

}

export class HistoryList extends React.Component<Props, State> {


  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
    };
  }

  public componentWillMount(): void {
    let probe: Probe = {
      id: Number(1),
    };
    this.props.onReadAllByProbe(probe);
  }

  public render(): JSX.Element {

    let historyList: JSX.Element = (
      <Container fluid>
        <Table celled selectable striped>
          <Table.Header>
            <Table.Row>
              <Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Type</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Message</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Created At</Table.HeaderCell>
              <Table.HeaderCell textAlign={'center'}>Created By</Table.HeaderCell>
            </Table.Row>
          </Table.Header>

          <Table.Body>
            {this.props.histories ? this.props.histories.map((history: History, index: number) => (
              <Table.Row key={index} >
                <Table.Cell textAlign={'center'}>{index + 1}</Table.Cell>
                <Table.Cell textAlign={'center'}>
                  {history.type.name}
                </Table.Cell>
                <Table.Cell>
                  {history.message}
                </Table.Cell>
                <Table.Cell>
                  {history.createDate}
                </Table.Cell>
                <Table.Cell>
                  {history.member.name}
                </Table.Cell>
              </Table.Row>
            )) : ''}
          </Table.Body>
          <Table.Footer>
            <Table.Row>
              <Table.HeaderCell colSpan='3'>
                <Menu floated='right' pagination>
                  <Menu.Item as='a' icon>
                    <Icon name='left chevron' />
                  </Menu.Item>
                  <Menu.Item as='a'>1</Menu.Item>
                  <Menu.Item as='a'>2</Menu.Item>
                  <Menu.Item as='a'>3</Menu.Item>
                  <Menu.Item as='a'>4</Menu.Item>
                  <Menu.Item as='a' icon>
                    <Icon name='right chevron' />
                  </Menu.Item>
                </Menu>
              </Table.HeaderCell>
            </Table.Row>
          </Table.Footer>
        </Table>

      </Container>
    );

    return (
      <ListContainer
        contents={historyList}
        data={this.props.histories}
      />
    );

  }

}


